@@ -8,21 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_cloudwatch._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_kinesis._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-eventbridge-kinesisstreams",
-    "1.180.0",
+    "2.2.0",
     __name__[0:-6],
-    "aws-eventbridge-kinesisstreams@1.180.0.jsii.tgz",
+    "aws-eventbridge-kinesisstreams@2.2.0.jsii.tgz",
 )
 
 __all__ = [
